#!/bin/sh

#-----------------------------------------------------------------------
# Bourne shell environment setup script for Geant4 11.0.4
#
# This script will configure your environment so that any Geant4 supplied
# tools, libraries and data are available in your PATH, library paths etc.
# Data libraries will only be setup if they were installed as part of the
# Geant4 installation.
#
# Source this script to perform the setup.
#
# This script is autogenerated by CMake DO NOT EDIT
#

#-----------------------------------------------------------------------
# Locate directory of self
#
# Self locate script when sourced
if [ -z "$BASH_VERSION" ]; then
  # Not bash, so rely on sourcing from correct location
  if [ ! -f geant4.sh ]; then
    echo 'ERROR: geant4.sh could NOT self-locate Geant4 installation'
    echo 'This is most likely because you are using ksh, zsh or similar'
    echo 'To fix this issue, cd to the directory containing this script'
    echo 'and source it in that directory.'
    return 1
  fi
  geant4_envbindir=$(pwd)
else
  g4sls_sourced_dir=$(dirname ${BASH_ARGV[0]})
  geant4_envbindir=$(cd $g4sls_sourced_dir > /dev/null ; pwd)
fi
      

#-----------------------------------------------------------------------
# Setup Geant4 binary and library paths...
#

if [ -z "${PATH-}" ] ; then
  export PATH="$geant4_envbindir"
else
  export PATH="$geant4_envbindir":${PATH}
fi


if [ -z "${LD_LIBRARY_PATH-}" ] ; then
  export LD_LIBRARY_PATH="`cd $geant4_envbindir/../lib/x86_64-linux-gnu > /dev/null ; pwd`"
else
  export LD_LIBRARY_PATH="`cd $geant4_envbindir/../lib/x86_64-linux-gnu > /dev/null ; pwd`":${LD_LIBRARY_PATH}
fi


#-----------------------------------------------------------------------
# Setup Third-party binary and library paths...
# - CLHEP
# - Builtin CLHEP used

# - XercesC

if [ -z "${LD_LIBRARY_PATH-}" ] ; then
  export LD_LIBRARY_PATH=/usr/lib/x86_64-linux-gnu
else
  export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:/usr/lib/x86_64-linux-gnu
fi


#-----------------------------------------------------------------------
# Resource file paths
# - Datasets
export G4NEUTRONHPDATA="/opt/geant4/geant4-data/G4NDL4.6"
export G4LEDATA="/opt/geant4/geant4-data/G4EMLOW8.0"
export G4LEVELGAMMADATA="/opt/geant4/geant4-data/PhotonEvaporation5.7"
export G4RADIOACTIVEDATA="/opt/geant4/geant4-data/RadioactiveDecay5.6"
export G4PARTICLEXSDATA="/opt/geant4/geant4-data/G4PARTICLEXS4.0"
export G4PIIDATA="/opt/geant4/geant4-data/G4PII1.3"
export G4REALSURFACEDATA="/opt/geant4/geant4-data/RealSurface2.2"
export G4SAIDXSDATA="/opt/geant4/geant4-data/G4SAIDDATA2.0"
export G4ABLADATA="/opt/geant4/geant4-data/G4ABLA3.1"
export G4INCLDATA="/opt/geant4/geant4-data/G4INCL1.0"
export G4ENSDFSTATEDATA="/opt/geant4/geant4-data/G4ENSDFSTATE2.3"


# - Fonts for Freetype

if [ -z "${TOOLS_FONT_PATH-}" ] ; then
  export TOOLS_FONT_PATH="`cd $geant4_envbindir/../share/Geant4-11.0.4/fonts > /dev/null ; pwd`"
else
  export TOOLS_FONT_PATH=${TOOLS_FONT_PATH}:"`cd $geant4_envbindir/../share/Geant4-11.0.4/fonts > /dev/null ; pwd`"
fi


#----------------------------------------------------------------------

